@@ -86,9 +86,7 @@ descriptions <- function(x) {
     
     for (nm in names(value)) {
       
-      if (is.null(x[[nm]])) 
-        stop(paste("Name not found:", nm))
-      else
+      if (!is.null(x[[nm]])) 
         attr(x[[nm]], "description") <- value[[nm]]
       
     }
